//
// Copyright (c) Microsoft Corporation.  All rights reserved.
//
//
// Use of this sample source code is subject to the terms of the Microsoft
// license agreement under which you licensed this sample source code. If
// you did not accept the terms of the license agreement, you are not
// authorized to use this sample source code. For the terms of the license,
// please see the license agreement between you and Microsoft or, if applicable,
// see the LICENSE.RTF on your install media or the root of your tools installation.
// THE SAMPLE SOURCE CODE IS PROVIDED "AS IS", WITH NO WARRANTIES OR INDEMNITIES.
//

#if !defined (CETOUCHVIEW_H)
#define CETOUCHVIEW_H

#include <windows.h>
#include <guts.h>
#include <ehm.h>
#include <tchddi.h>
#include <sync.hxx>
#include <touchperf.h>
#include <mdpgperf.h>
#include <prsht.h>
#include "resource.h"

#define TOUCHPOINT_RADIUS       (5)             // radius of the ellipse showing the touch point

typedef struct {
    DWORD   dwDisplayMode,
            dwShowTrailing,
            dwShowData,
            dwShowContact,
            dwRawOffsetX,
            dwRawOffsetY,
            dwGestureOffsetX,
            dwGestureOffsetY,
            dwButtonX,
            dwButtonY,
            dwWindowX,
            dwWindowY,
            dwBkMode,
            dwBkColor,
            dwDMColor,
            dwPANColor,
            dwSCROLLColor,
            dwSELECTColor,
            dwDSELECTColor,
            dwHOLDColor,
            dwShowDM,
            dwShowPAN,
            dwShowSCROLL,
            dwShowSELECT,
            dwShowDSELECT,
            dwShowHOLD,
            dwShowStatistics,
            dwShowInitialWarning,
            dwShowIDWarning,
            dwShowContactsWarning,
            dwContactsMin,
            dwContactsMax,
            dwMacroMode;
    LPTSTR  szFileName,
            szBkImage;
} REGSETTINGS;

#define BUTTON_WIDTH        (100)
#define BUTTON_HEIGHT       (40)
#define DATAWIN_WIDTH       (700)
#define DATAWIN_HEIGHT      (45)

enum {
    DISPLAYMODE_RAW = 1,
    DISPLAYMODE_GESTURE,
    DISPLAYMODE_BOTH,
    DISPLAYMODE_TEXT,
    DISPLAYMODE_BAR
};

enum {
    BKMODE_COLOR = 0,
    BKMODE_IMAGE
};

enum {
    MACROMODE_PLAYBACK = 0,
    MACROMODE_RECORD
};

extern HBITMAP g_hBkImage;
extern BITMAP g_bmBkImage;

void PaintCtrlArea(HDC hdc);
BOOL SwapDM (HWND hwnd, BOOL fUseDM);
BOOL InitScreenObjects();
void DrawGestureDot(GESTUREINFO *pgi);
void PanProc(GESTUREINFO *pgi);

LPCTSTR LoadStringZ ( UINT id );
LPWSTR StrDup ( LPWSTR lpstr );

void OptionsDialog ( HWND hwndParent );
BOOL DisplayModeTabDlgProc ( HWND hDlg, UINT uMsg, WPARAM wParam, LPARAM lParam );
BOOL DisplayOffsetTabDlgProc ( HWND hDlg, UINT uMsg, WPARAM wParam, LPARAM lParam );
BOOL UserInterfaceTabDlgProc ( HWND hDlg, UINT uMsg, WPARAM wParam, LPARAM lParam );
BOOL GestureTabDlgProc ( HWND hDlg, UINT uMsg, WPARAM wParam, LPARAM lParam );
BOOL WarningsTabDlgProc ( HWND hDlg, UINT uMsg, WPARAM wParam, LPARAM lParam );
BOOL RecPlayTabDlgProc ( HWND hDlg, UINT uMsg, WPARAM wParam, LPARAM lParam );
BOOL UpdateBkBitmap ( LPTSTR szFileName );
void ClearScreen ( void );
void ClearRawList ( void );

#define WM_TRIGGER_FILTER       (WM_APP + 0)
#define WM_SHOW_STATISTICS      (WM_APP + 1)
#define WM_SHOW_CONTACTSWARNING (WM_APP + 2)

typedef struct
{
    int         idsTitle;     // RCID of title of prop-page
    int         iddDlg;       // RCID of dlg
    DLGPROC     pfnDlg;       // Tabs dialog proc.
} TABINFO, *PTABINFO;

#define NUM_BRUSHES     (GID_LAST + 2)
#define BRUSH_BLACK     (GID_LAST)
#define BRUSH_RED       (GID_LAST + 1)

extern HBRUSH g_rgBrushes[NUM_BRUSHES];

#endif  // CETOUCHVIEW_H
